#
# spec file for package os-prober
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           os-prober
Version:        1.61
Release:        20.5
Summary:        Probes disks on the system for installed operating systems
License:        GPL-2.0+
Group:          System/Boot

Url:            http://kitenet.net/~joey/code/os-prober/
Source0:        http://ftp.de.debian.org/debian/pool/main/o/os-prober/%{name}_%{version}.tar.gz
Source1:        COPYING-note.txt
# move newns binary outside of os-prober subdirectory, so that debuginfo
# can be automatically generated for it
Patch0:         os-prober-newnsdirfix.patch
# PATCH-FIX-OPENSUSE: Fix spelling of SUSE aj@suse.de
Patch1:         os-prober-SUSE.patch
# PATCH-FIX-OPENSUSE: Fix parsing of grub.cfg [bnc#796919]
Patch3:         os-prober-1.49-fix-grub2.cfg-parsing.patch
# PATCH-FIX-OPENSUSE: Do not try to mount LVM2 PV [bnc#798604]
Patch4:         os-prober-1.49-skip-LVM2_member.patch
# PATCH-FIX-OPENSUSE: Use correct name for grub2-mount
Patch5:         os-prober-1.49-grub2-mount.patch
# PATCH-FIX-OPENSUSE: Probe also unpartitioned Linux MD devices (bnc#811006)
Patch7:         os-prober-probe-MD-devices.patch
# PATCH-FIX-OPENSUSE: Detect linux secure boot entries too (bnc#810912)
Patch8:         os-prober-linux-secure-boot.patch
# PATCH-FIX-OPENSUSE: btrfs support from Fedora (rediffed)
Patch9:         os-prober-btrfsfix.patch
# PATCH-FIX-OPENSUSE: difference between upstream and our previous scripts
Patch10:        os-prober-EFI-openSUSEfy.patch
# PATCH-FIX-OPENSUSE: accept ESP on IMSM MD raid (bnc#818871)
Patch11:        os-prober-accept-ESP-on-IMSM.patch
# PATCH-FIX-OPENSUSE: don't modprobe all file system modules and don't test mount on unknown partition (bnc#851722)
Patch12:        os-prober-dont-load-all-fs-module-and-dont-test-mount.patch
# PATCH-FIX-OPENSUSE: fix os-prober entries for distro on btrfs root-fs not created (bnc#846003)
Patch13:        os-prober-fix-btrfs-subvol-mounted-tests.patch
# PATCH-FIX-SLE: fix os-prober creates many unusuable entries on multipath disk (bnc#875327)
Patch14:        os-prober-skip-part-on-multipath.patch
# PATCH-FIX_SLE: os-prober: dmraid is called without a device list for every partition (bnc#883453)
Patch15:        os-prober-call-dmraid-once.patch
# PATCH-FIX_OPENSUSE os-prober: Improve btrfs handling on os-probing for grub2
Patch16:        Improve-btrfs-handling-on-os-probing-for-grub2.patch
# PATCH-FIX-SLE: fix os-prober mount error, no such file or directory (bsc#931955)
Patch17:        os-prober-btrfs-absolute-subvol.patch
# PATCH-FIX-OPENSUSE: also skip legacy grub if /boot/grub2/grub.cfg is present (bsc#956337)
Patch18:        os-prober-40grub-check-grub2.patch
# PATCH-FIX-UPSTREAM: fix os-prober misinterprets Windows 8 to be Vista (bsc#910654)
Patch19:        os-prober-grep-for-windows-bcd-file.patch
# PATCH-FIX-UPSTREAM: fix os-prober is missing support for Windows 10 detection (bsc#947487)
Patch20:        os-prober-properly-detect-Windows-10.patch
# PATCH-FIX-OPENSUSE: detect os on default subvolume in snapshot (bsc#954225)
Patch21:        os-prober-btrfs-snapshot-detection.patch
# PATCH-FIX-OPENSUSE: os-prober update broke Linux detection (bsc#957018)
Patch22:        os-prober-btrfs-always-detect-default.patch
# PATCH-FIX-OPENSUSE: y2base runs at 100% cpu busy from beginning in installation of files to completion (bsc#953987)
Patch23:        os-prober-linux-distro-avoid-expensive-ld-file-test.patch
Requires:       /bin/grep
Requires:       /bin/sed
Requires:       /sbin/modprobe
Requires:       btrfsprogs
Requires:       coreutils
Requires:       dmraid
Requires:       lvm2
Requires:       udev
Requires:       util-linux
%if 0%{?suse_version} >= 1315
# For logger utility
Requires:       util-linux-systemd
%endif

%description
This package detects other OSes available on a system and outputs the results
in a generic machine-readable format. Support for new OSes and Linux
distributions can be added easily.

%prep
%setup -q -n %{name}-%{version}
cp %SOURCE1 .
%patch0 -p1
%patch1 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1

%build
make %{?_smp_mflags} CC="%__cc" CFLAGS="%{optflags}"

%install
install -m 0755 -d %{buildroot}%{_bindir}
install -m 0755 -d %{buildroot}%{_localstatedir}/lib/%{name}

install -m 0755 -p os-prober linux-boot-prober %{buildroot}%{_bindir}
install -m 0755 -Dp newns %{buildroot}%{_libexecdir}/newns
install -m 0644 -Dp common.sh %{buildroot}%{_datadir}/%{name}/common.sh

%ifarch m68k
ARCH=m68k
%endif
%ifarch ppc ppc64
ARCH=powerpc
%endif
%ifarch sparc sparc64
ARCH=sparc
%endif
%ifarch %{ix86} x86_64
ARCH=x86
%endif

for probes in os-probes os-probes/mounted os-probes/init \
              linux-boot-probes linux-boot-probes/mounted; do
        install -m 755 -d %{buildroot}%{_libexecdir}/$probes
        cp -a $probes/common/* %{buildroot}%{_libexecdir}/$probes
        if [ -e "$probes/$ARCH" ]; then
                cp -a $probes/$ARCH/* %{buildroot}%{_libexecdir}/$probes
        fi
done
if [ "$ARCH" = x86 ]; then
        install -m 755 -p os-probes/mounted/powerpc/20macosx \
            %{buildroot}%{_libexecdir}/os-probes/mounted
fi

%files
%defattr(-,root,root,-)
%doc README TODO debian/copyright debian/changelog COPYING-note.txt
%{_bindir}/*
%{_libexecdir}/linux-boot-probes
%{_libexecdir}/newns
%{_libexecdir}/os-probes
%{_datadir}/%{name}
%{_localstatedir}/lib/%{name}

%changelog
* Mon Dec  7 2015 mchang@suse.com
- The ld file tests cost too much as it transversed all files in
  the given wildcard directory and path, we should avoid when not
  necessary. (bsc#953987)
  * added os-prober-linux-distro-avoid-expensive-ld-file-test.patch
- Fix missing linux16/initrd16 parsing in entry result
- Fix kernelfile path if separate boot partition on btrfs
  * modified Improve-btrfs-handling-on-os-probing-for-grub2.patch
* Thu Dec  3 2015 mchang@suse.com
- fix os-prober failed to detect os in btrfs root tree (bsc#957018)
  * added os-prober-btrfs-always-detect-default.patch
* Thu Nov 26 2015 lnussel@suse.de
- detect os on default subvolume in snapshot (bsc#954225)
  (os-prober-btrfs-snapshot-detection.patch)
* Thu Nov 26 2015 mchang@suse.com
- fix os-prober misinterprets Windows 8 to be Vista (bsc#910654)
  * add os-prober-grep-for-windows-bcd-file.patch
- include patch from upstream to fix os-prober is missing support for
  Windows 10 (bsc#947487)
  * added os-prober-properly-detect-Windows-10.patch
* Tue Nov 24 2015 arvidjaar@gmail.com
- add os-prober-40grub-check-grub2.patch
  * also skip legacy grub if /boot/grub2/grub.cfg is present, not only
    /boot/grub/grub.cfg (bsc#956337)
* Wed Sep 30 2015 mchang@suse.com
- add os-prober-btrfs-absolute-subvol.patch
  * fix os-prober mount error, no such file or directory (bsc#931955)
* Fri May 29 2015 eich@suse.com
- Improve-btrfs-handling-on-os-probing-for-grub2.patch
  * Improve btrfs handling on os-probing for grub2 (bsc#892364)
* Tue Aug 19 2014 mchang@suse.com
- requires util-linux-systemd (bnc#892337)
* Fri Jun 20 2014 jeffm@suse.com
- add os-prober-call-dmraid-once.patch
  * fix os-prober: dmraid is called without a device list for every
    partition (bnc#883453)
* Thu May 29 2014 mchang@suse.com
- add os-prober-skip-part-on-multipath.patch
  * fix os-prober creates many unusuable entries on multipath disk
    (bnc#875327)
* Wed Jan 15 2014 arvidjaar@gmail.com
- fix os-prober-btrfsfix.patch - current "btrfs subvolume list -s"
  adds some extra fields. Adjust field number to get subvolume name.
* Wed Dec 18 2013 mchang@suse.com
- add os-prober-fix-btrfs-subvol-mounted-tests.patch
  * move btrfs subvolume mounted tests after regualr rootfs tree
    tests to make sure that root and subvolume fs tree are tested.
  * the test order is just a preference, assuming that distribution
    are installed to root fs tree more likely than to a subvolume.
* Fri Dec  6 2013 mchang@suse.com
- add os-prober-dont-load-all-fs-module-and-dont-test-mount.patch
  * don't modprobe that many kernel file system modules before mount
    as mount will take care that for us (bnc#782689)
  * don't test mount on partitions without any known file system
    detected (bnc#851722)
* Thu Nov  7 2013 mchang@suse.com
- add require btrfsprogs
* Sun Aug 18 2013 arvidjaar@gmail.com
- add os-prober-accept-ESP-on-IMSM.patch
  * accept EFI partition on IMSM MD array (bnc#818871)
  * fix DOS partition table detection
* Fri May 31 2013 arvidjaar@gmail.com
- update to os-prober 1.61. Highlights:
  * Fix detection of Fedora and other distros that moved /lib into /usr
  * sed off (hdn,n) from the front of an initrd path
  * Add support to detect BSD systems
  * add support for probing EFI System Partition
- rediff
  * os-prober-1.49-fix-grub2.cfg-parsing.patch - part implemented
    differenty upstream; added additional os-prober entries detection based
    on menu entry ID as suggested by Vladimir Serbienko
  * os-prober-1.49-grub2-mount.patch
  * os-prober-SUSE.patch
  * os-prober-linux-secure-boot.patch
- drop upstream patches
  * os-prober-usr_lib-detection.patch
  * os-prober-skip-MS-legacy-on-UEFI.patch together with 05efi, efi-20microsoft,
    efi-10elilo
- add
  * os-prober-btrfsfix.patch - support btrfs. Patch from Fedora with
    all unrelated changes cleaned out
  * os-prober-EFI-openSUSEfy.patch - cosmetic changes between our scripts
    and version adopted upstream
* Fri Apr  5 2013 arvidjaar@gmail.com
- add os-prober-linux-secure-boot.patch (bnc#810912)
  * recognize linuxefi/initrdefi too
* Fri Mar 22 2013 arvidjaar@gmail.com
- add os-prober-probe-MD-devices.patch (bnc#811006)
  * probe also Linux MD devices
* Sun Mar  3 2013 arvidjaar@gmail.com
- 05efi - accept FUSE as valid filesystem too (bnc#807190)
* Fri Feb  8 2013 arvidjaar@gmail.com
- os-prober-usr_lib-detection.patch - fix detection of linux distro
  which moved /lib to /usr/lib (e.g. Fedora)
* Sat Jan 19 2013 arvidjaar@gmail.com
- os-prober-1.49-grub2-mount.patch (bnc#767272)
  * In openSUSE grub-mount is called grub2-mount
* Sat Jan 19 2013 arvidjaar@gmail.com
- fix os-prober-1.49-fix-grub2.cfg-parsing.patch (bnc#799457)
  * initrd was missing
  * entries sometimes were not emitted
* Wed Jan 16 2013 arvidjaar@gmail.com
- add os-prober-1.49-skip-LVM2_member.patch (bnc#798604)
  * do not try to mount LVM2 PV
* Tue Jan  8 2013 arvidjaar@gmail.com
- add os-prober-1.49-fix-grub2.cfg-parsing.patch (bnc#796919)
* Fri Jan  4 2013 arvidjaar@gmail.com
- add support for chainloading another UEFI bootloader (bnc#775610)
  * 05efi - top level driver to search ESP
  * efi-20microsoft - support Microsoft UEFI bootloader
  * efi-10elilo - support ELILO UEFI bootloader (Agnelo de la Crotche)
- skip legacy Microsoft bootloader on UEFI (bnc#775610)
* Mon Dec 19 2011 aj@suse.de
- Clarify license.
* Thu Dec  8 2011 aj@suse.de
- Update to 1.49:
  * MeeGo detection support
  * Bugfixes
* Thu Dec  8 2011 coolo@suse.com
- this seems to be "GPL" as it was understood 2004, so guessing
  GPL-2.0+
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Tue Jul 12 2011 aj@suse.de
- Create new package.
